Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorBrecht Van Lommel <brechtvanlommel@pandora.be>2011-10-22 19:35:49 +0400
committerBrecht Van Lommel <brechtvanlommel@pandora.be>2011-10-22 19:35:49 +0400
commite417e011d558693b9ff9cd048efe9cbe79da74be (patch)
tree36612e30bf5c561051635c8eef7180d29251e846 /source/blender/editors/interface/interface_icons.c
parentc1de5cc83829b65094eee024af10928bd13261ce (diff)
Code cleanup: file operations merged into single header, some function names
made less cryptic and changed to indicate if they work on files or directories.
Diffstat (limited to 'source/blender/editors/interface/interface_icons.c')
-rw-r--r--source/blender/editors/interface/interface_icons.c9
1 files changed, 4 insertions, 5 deletions
diff --git a/source/blender/editors/interface/interface_icons.c b/source/blender/editors/interface/interface_icons.c
index c1418c5b6e8..f987aa9c4e6 100644
--- a/source/blender/editors/interface/interface_icons.c
+++ b/source/blender/editors/interface/interface_icons.c
@@ -47,7 +47,6 @@
#include "BLI_math.h"
#include "BLI_blenlib.h"
-#include "BLI_storage_types.h"
#include "BLI_utildefines.h"
#include "DNA_brush_types.h"
@@ -609,11 +608,11 @@ static void init_iconfile_list(struct ListBase *list)
if(icondir==NULL)
return;
/* since BLI_getdir changes the current working directory, restore it
back to old value afterwards */
- if(!BLI_getwdN(olddir, sizeof(olddir)))
+ if(!BLI_current_working_dir(olddir, sizeof(olddir)))
restoredir = 0;
- totfile = BLI_getdir(icondir, &dir);
+ totfile = BLI_dir_contents(icondir, &dir);
if (restoredir && !chdir(olddir)) {} /* fix warning about checking return value */
for(i=0; i<totfile; i++) {
@@ -662,7 +661,7 @@ static void init_iconfile_list(struct ListBase *list)
}
}
- /* free temporary direntry structure that's been created by BLI_getdir() */
+ /* free temporary direntry structure that's been created by BLI_dir_contents() */
i= totfile-1;
for(; i>=0; i--){
@@ -609,11 +608,11 @@ static void init_iconfile_list(struct ListBase *list)
if(icondir==NULL)
return;
- /* since BLI_getdir changes the current working directory, restore it
+ /* since BLI_dir_contents changes the current working directory, restore it
back to old value afterwards */